/* Copyright (c) Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 *
 * @defgroup app_string_print Printing library
 * @{
 * @ingroup libs
 */

#ifndef UART_DEBUG_H
#define UART_DEBUG_H
#include <stdint.h>

/**@brief Decomposes char array and send chars through UART TX.
 *
 * @param[in]     char_array     Message to sent through UART.
 */
void print_string(char * char_array);

/**@brief Converts hex number into char and send it through UART TX.
 *
 * @param[in]     number        Number to send.
 * @param[in]     byte_size     Byte size of number to send.
 */
void print_hex(uint32_t number, uint8_t byte_size);

/**@brief Function used to report event related to source code.
 *
 * @details Function used to provide more information of occurred errors.
 *          Might point on a line and a file when specific action occurred.
 *
 * @param[in]     line_num        Number of line in a source file.
 * @param[in]     file_name       Source file file-name.
 */
void print_file_and_line(uint16_t line_num, const uint8_t *file_name);

#endif /* UART_DEBUG_H */

/** @} */


