/* Copyright (c) Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 *
 * @defgroup pru_config PRU profile configuration
 * @{
 * @ingroup profile
 */

#ifndef __PRU_CONFIG_H__
#define __PRU_CONFIG_H__

#define PRU_ADV_DEVICE_NAME                    "WPT PRU"               /**< Device name. */
#define PRU_ADV_INTERVAL                       32                      /**< The advertising interval (in units of 0.625 ms. This value corresponds to 20 ms). */
#define PRU_PROTOCOL_REVISION                  1                       /**< Protocol revision */
#define PRU_HW_REVISION                        100                     /**< Revision of the PRU HW. */
#define PRU_FW_REVISION                        200                     /**< Revision of the PRU SW. */
#define PRU_MIN_CONN_INTERVAL                  50                      /**< Minimum acceptable connection interval PRU defined by spec, in 1.25 ms units */
#define PRU_MAX_CONN_INTERVAL                  250                     /**< Maximum acceptable connection interval, in 1.25 ms units */
#define PRU_SLAVE_LATENCY                      0                       /**< Slave latency. */
#define PRU_CONN_SUP_TIMEOUT                   100                     /**< Connection supervisory timeout (10 ms uints > 1 sec), ref. 5.2.2.2 */
#define PRU_TIME_SET_SUPPORT                   0                       /**< Time set support (0=no support, 1 = support) */
#define PRU_CHARGE_COMPLETE_ADV_WAIT_TIME_MS   600                     /**< Period that power must be applied in PRU Boot state for a charged device before trying to connect to a charging PTU [ms] */
#define PRU_MAX_APP_TIMERS                     3                       /**< Maximium timers to be instansiated in application  */
#define PRU_CHARGE_COMPLETE_CONN_MODE_ENABLE   0                       /**< Indicates whether to enable Charge Complete Connected Mode. */
#define PRU_SECURITY                           BLE_WPTS_SEC_MODE_1_LEVEL_1 /**< Security setting for WPT attribute table */
#define PRU_SEC_MIN_KEYSIZE                    7                       /**< Minimum keysize [7,16] to be used for encryption [bytes]. */
#define PRU_SEC_MAX_KEYSIZE                    16                      /**< Minimum keysize [7,16] to be used for encryption [bytes]. */
#define PRU_POWER_CONTROL_ALG_PREFERENCE       0                       /**< Power control algorithm preference. 0 = Vrect_min_error, 1 = max system efficiency */
#define PRU_CCP_CONNECT_MODE_SUPPORTED         0                       /**< Charge complete connected mode supported */
#define PRU_RESET_POWER_ADJUSTED_MS            1000                    /**< How long should PRU wait after setting adjusted bit before resetting it? [ms] */
#define PRU_BUTTON_PRESS_LENGTH_DFU_MS         5 * 1000                /**< Button needs to be pressed for 5 seconds in order to start DFU mode. */

#endif /* __PRU_CONFIG_H__ */

/** @} */
