/* Copyright (c) Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 *
 * @defgroup pru_hw_config PRU HW dependent configuration
 * @{
 * @ingroup hal
 */

#ifndef __PRU_HW_CONFIG_H__
#define __PRU_HW_CONFIG_H__

#define PRU_VRECT_BOOT                         6000                            /**< Boot VRECT voltage [mV]. Below this level, the PRU can not enter the Boot State. */
#define PRU_VRECT_UVLO                         4000                            /**< Under Voltage Lock Out VRECT voltage. Below this level, the PRU may not enable MCU and communication module. [mV].*/
#define PRU_VRECT_MIN                          7000                            /**< Minimum operational VRECT voltage [mV]. Below this voltage, PRUs may not deliver full power. */
#define PRU_VRECT_SET                          10000                           /**< PRUs preferred VRECT voltage [mV].*/
#define PRU_VRECT_HIGH                         15000                           /**< Maximum operational VRECT voltage [mV]. */
#define PRU_VRECT_MAX                          19000                           /**< PRUs maximum allowable VRECT voltage [mV]. */
#define PRU_VRECT_HIGH_SUSTAIN_MS              5000                            /**< Number of sensor measurements that the PRU can tolerate VRECT to be greater than VRECT_HIGH [ms]. */
#define PRU_TEMP_MAX                           90                              /**< PRUs maximum allowable temperature [Deg C].*/
#define PRU_DELTA_R1_VALID                     0                               /**< Delta R1 field in static parameters is valid. */
#define PRU_DELTA_R1                           1500                            /**< Delta R1 caused by PRU. */

#define PRU_CATEGORY                           BLE_WPTS_PRU_CATEGORY_NO_IMP_SHIFT   /**< PRU Category. */
#define PRU_ANTENNA_GAIN_KNOWN                 false                                 /**< true = Use the value PRU_ANTENNA_GAIN when calculating the advertising payload, false = set the PRU_Gain advertising bits to all 1's */
#define PRU_ANTENNA_GAIN                       0                                     /**< Gain of TX antenna. */
#define PRU_TX_POWER_KNOWN                     false                                 /**< true = Use the value PRU_TX_POWER_KNOWN when calculating the advertising payload, false = set the PRU_Power advertising bits to all 1's */
#define PRU_TX_POWER_LEVEL                     0                                     /**< Low TX power level to avoid connecting to distant PTU's when testing. */
#define PRU_SENSORS_TIMER_PERIOD_MS            50                                    /**< Sensor measurement period (ms). */
#define PRU_NFC_RECEIVER_SUPPORTED             0                                     /**< NFC receiver supported */
#define PRU_SEPARATE_BTLE_RADIO_SUPORTED       0                                     /**< Separate BTLE radio in PRU */
#define PRU_CCP_ADJUST_POWER_CAPABILITY        1                                     /**< Adjust power capability */
#define PRU_PRECT_MAX                          90                                    /**< PRUs maximum rated PRECT power [mW*100]. */

/******************************************************************************
 * Suggested default values for e.g. emulated HAL libraries.
 ******************************************************************************/

#define PRU_VRECT_DEFAULT                      PRU_VRECT_SET              /**< [mV] */
#define PRU_TEMPERATURE_DEFAULT                (PRU_TEMP_MAX / 2);        /**< [deg C] */
#define PRU_VOUT_DEFAULT                       (4000)                          /**< [mV] */
#define PRU_IOUT_DEFAULT                       (1)                             /**< [mA] */
#define PRU_IRECT_DEFAULT                      (1)                             /**< [mA] */
#define PRU_ADJUSTED_DEFAULT                   (1)                           /**< [bool] */

#endif /* __PRU_HW_CONFIG_H__ */
/** @} */
