/* Copyright (c) 2013 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 *
 * @defgroup pru_api PRU profile API
 * @{
 * @ingroup profile
 */

#ifndef __PRU_H__
#define __PRU_H__

#include "app_timer.h"
#include "ble_wpts.h"
#include "pru_sm.h"
#include "pru_config.h"

typedef void (*app_sm_evt_handler_t)
    (pru_sm_signal_type_t signal, const pru_sm_state_vars_t * p_state_vars);  /**< Application State machine event handler. */

typedef void (*pru_sm_handler_t)(pru_sm_signal_type_t evt);                   /**< PRU State machine event handler. */

#define APP_TIMER_PRESCALER                  0                                          /**< Prescaling for internal timers. */
#define APP_TIMER_OP_QUEUE_SIZE              10                                         /**< Max number of internal timers. */

#if(PRU_CHARGE_COMPLETE_CONN_MODE_ENABLE)
    #error PRU charge complete connected mode not implemented.
#endif
/******************************************************************************/
/** @name General API functions
 *  @{ */
/******************************************************************************/

/**@brief Initialize PRU.
 * This function must be called before any other PRU function can be called.
 * @param sm_evt_handler Optional handle state machine event callback. Set to NULL if no callback is required.
 */
void pru_init(app_sm_evt_handler_t sm_evt_handler);

/**@brief Enable the PRU profile.
 * When enabled sensor reading and signal generation will be enabled.
 */
void pru_start(void);

/**@brief Handle BLE event.
 */
void pru_on_ble_evt(ble_evt_t * p_ble_evt);

#ifdef DEBUG_OUT_ENABLE
    void wpts_test_evt_handle_cb(ble_wpts_t * p_wpts, ble_wpts_evt_t * p_evt);
#endif //DEBUG_OUT_ENABLE

/** @} */

#endif /* __PRU_H__ */
/** @} */
