/* Copyright (c) 2013 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 *
 * @defgroup pru_pstorage PRU persistant storage API
 * @{
 * @ingroup profile
 */

#ifdef PRU_PSTORAGE_ENABLE

#ifndef __PRU_PSTORAGE_H__
#define __PRU_PSTORAGE_H__


#include <stdint.h>
#include <stdbool.h>

/******************************************************************************/
/** @name Persistant Storage API functions
 *  @{ */
/******************************************************************************/

/**@brief PRU pstorage data container. */
typedef struct pru_pstorage_appdata {
    uint32_t padding;   /**< Empty data used to ensure word alignment, as this is required when performing flash operations. */
    uint8_t charge_complete; /**< Was charge complete set?. */
    /** TODO: Expand with more variables to store more data */
} pru_pstorage_appdata_t;


/**@brief Handles system callbacks.
 *
 * @param[in]   event Event identifier.
 *
 */
void pru_pstorage_sys_evt_handler(uint32_t event);


/**@brief Writes application data to flash.
 *
 * @param[in]   p_appdata Pointer to data to be written.
 *
 */
void pru_pstorage_write(pru_pstorage_appdata_t * p_appdata);


/**@brief Read status of pstorage operation
 *
 * @param[in]   p_complete Is the current action completed?
 *
 * @param[in]   p_success Was the last action successful?
 */
void pru_pstorage_status(bool *p_complete, bool *p_success);


/**@brief Reads application data from flash.
 *
 * @param[in]   p_appdata Pointer to where data will be saved.
 *
 * @return      true when application data found, false otherwise.
 */
bool pru_pstorage_read(pru_pstorage_appdata_t * p_appdata);


/**@brief Erase all of PRU appdata.
 */
void pru_pstorage_erase_appdata(void);

#endif /* __PRU_PSTORAGE_H__ */


/** @} */
#endif // PRU_PSTORAGE_ENABLE
/** @} */
