/* Copyright (c) 2013 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 *
 * @defgroup sm_pru PRU State Machine
 * @{
 * @ingroup sm
 * @brief
 */

#ifndef PRU_SM_PRU_H__
#define PRU_SM_PRU_H__


/**@brief PRU states. */
typedef enum
{
    PRU_SM_STATE_NULL,
    PRU_SM_STATE_BOOT,
    PRU_SM_STATE_PRU_ON,
    PRU_SM_STATE_SYSTEM_ERROR,
    PRU_SM_STATE_COUNT
} pru_sm_state_t;

/**@brief PRU state machine signal type. */
typedef enum
{
    PRU_SM_SIGNAL_NULL,                /**< Null signal, used when changing states. */
    PRU_SM_SIGNAL_CHARGE_START,        /**< Charge command received */
    PRU_SM_SIGNAL_CHARGE_STOP,         /**< Stop charging command received */
    PRU_SM_SIGNAL_POWER_APPLIED,       /**< Sensor measurement: V_RECT >= V_RECT_BOOT. */
    PRU_SM_SIGNAL_POWER_REMOVED,       /**< Sensor measurement: V_RECT <= V_RECT_UVLO. */
    PRU_SM_SIGNAL_CHARGE_COMPLETE,     /**< Sensor measurement: V_OUTT >= V_OUT_CHARGED. */
    PRU_SM_SIGNAL_DISCONNECTED,        /**< PRU has been disconnected. Not shown in state diagram, see 5.3.7.3 in BSS 1.3. */
    PRU_SM_SIGNAL_SYSTEM_ERROR,        /**< Over-current, over_voltage or over_temperature trigger. */
    PRU_SM_SIGNAL_COUNT                /**< How many SM signals are defined? */
} pru_sm_signal_type_t;

/******************************************************************************/
/** @name PRU state functions.
 *  @{ */
/******************************************************************************/

/**@brief State machine state variables. */
typedef struct
{
    pru_sm_state_t prev_state;                               /**< Previous state. */
    pru_sm_state_t current_state;                            /**< Current state. */
    pru_sm_state_t next_state;                               /**< Next state. */
} pru_sm_state_vars_t;

/**@brief Execute state machine
 *
 * @param[in] sig Signal to handle
 * @param[out] p_state Pointer to PRU state variable
 * @return The current state after executing the event.
 */
pru_sm_state_t pru_sm_execute(pru_sm_signal_type_t sig, pru_sm_state_vars_t * p_state);


/** @} */
#endif // PRU_SM_PRU_H__
/** @} */
//lint -restore

