/* Copyright (c) 2013 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 *
 * @defgroup ptu_api PTU profile API
 * @{
 * @ingroup profile
 */

#ifndef __PTU_H__
#define __PTU_H__

#include <stdint.h>

#include "wpt.h"
#include "ble.h"
#include "app_timer.h"
#include "ptu_sm.h"

typedef void (* ptu_sm_handler_t)(ptu_sm_signal_type_t signal); /**< State machine event handler. */
typedef void (*app_sm_evt_handler_t) (ptu_sm_signal_type_t signal, const ptu_sm_state_vars_t * p_state_vars); /**< Application State machine event handler. */

#define APP_TIMER_PRESCALER                  0                      /**< Prescaling for internal timers. */
#define APP_TIMER_OP_QUEUE_SIZE              19                     /**< Max number of internal timers. */

#define PTU_SM_CURRENT_STATE()  ptu_sm_execute((ptu_sm_signal_type_t)NULL, NULL) /**< Get current state of PTU state machine. */

/******************************************************************************/
/** @name General API functions
 *  @{ */
/******************************************************************************/

/**@brief Initialize PTU. This function must be called before any other PTU
 * function can be called.
 * @param sm_evt_handler Optional handle state machine event callback. Set to NULL if no callback is required.
 */
void ptu_init(app_sm_evt_handler_t sm_evt_handler);

/**@brief Dispatches a BLE stack event to PTU.
 *
 * @param[in]   p_ble_evt   Bluetooth stack event.
 */
void ptu_on_ble_evt(ble_evt_t * p_ble_evt);

/**@brief Start ptu profile. Here "start" means that profile can start generating
 * events through ptu_evt_handler().
 */
void ptu_start(void);

/** @} */

#endif /* __PTU_H__ */
/** @} */
