/* Copyright (c) 2013 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 *
 * @defgroup ptu_conn_man PTU connection manager API
 * @{
 * @ingroup profile
 */

#ifndef __PTU_CONN_MAN_H__
#define __PTU_CONN_MAN_H__

#include <stdbool.h>
#include <stdint.h>

#include "ptu_registry.h"
#include "ptu.h"

/**@brief Initialize connection manager.
 *
 * @param[in] sm_handler State machine event handler
 * @return NRF_ERROR_INVALID_PARAM if sm_handler is NULL, otherwise NRF_SUCCESS.
 */
uint32_t ptu_cm_init(ptu_sm_handler_t sm_handler);

/**@brief Disconnect and/or unregister any device.
 *
 * @param[in] reg_item_p reg_item.
 */
void ptu_cm_remove_device(ptu_reg_item_t * reg_item_p);

/**@brief Get mode transition status.
 *
 * @retval true if mode transition in progress
 */
bool ptu_cm_mode_trans_in_progress(void);

/**@brief Enable scanning.
 */
void ptu_cm_scan_enable(void);

/**@brief Disable scanning.
 */
void ptu_cm_scan_disable(void);

/**@brief BLE event handler.
 *
 * @param[in] p_ble_evt ble event data.
 */
void ptu_cm_on_ble_evt(ble_evt_t * p_ble_evt);

/**@brief Handle service events.
 *
 * @param[in] p_wpts_c handles.
 * @param[in] p_wpts_c_evt event data.
 */
void ptu_cm_on_wpt_service_evt(ble_wpts_c_t * p_wpts_c, ble_wpts_c_evt_t * const p_wpts_c_evt);

/** @brief Disconnect all PRUs.
 */
void ptu_cm_disconnect_all(void);

/** @brief Issue read request for the PRU dynamic characteristic to all registerred PRUs.
 */
void ptu_cm_dynamic_read_all(void);

#endif /* __PTU_CONN_MAN_H__ */

/** @} */


