/* Copyright (c) Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 */

#ifndef PTU_LATCHING_FAULT_H__
#define PTU_LATCHING_FAULT_H__

#include <stdint.h>
#include "ptu.h"


/**@brief Handle the entry of latching fault state.
 * @param previous The previous state of the PTU state machine.
 * @return INVALID_STATE if current state is not latching fault, SUCCESS otherwise.
 */
uint32_t ptu_latching_fault_entered(ptu_sm_state_t previous);

/**@brief Initialize latching fault module.
 * @param sm_handler The state machine handler of the PTU.
 * @return INVALID_PARAM if sm_handler is NULL, SUCCESS otherwise.
 */
uint32_t ptu_latching_fault_init(ptu_sm_handler_t sm_handler);

#endif //PTU_LATCHING_FAULT_H__

/** @} */
//lint -restore
