/* Copyright (c) 2013 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 *
 * @defgroup ptu_power_ctl PTU power control API
 * @{
 * @ingroup profile
 */

#ifndef __PTU_PCTL_H__
#define __PTU_PCTL_H__

#include <stdint.h>
#include <stdbool.h>

#include "wpt.h"

/** @brief Perform power control adjustments.
 */
void ptu_power_ctrl_adjust(void);

/** @brief Perform power control adjustments.
 *  @param level The poweramp input to set
 *  @retval NRF_SUCCESS if successfus, error code otherwise.
 */
uint32_t ptu_power_ctrl_set_poweramp_input(uint16_t level);

/** @brief Enable/Disable adjustments of power amplifier (I_TX_COIL).
 *  @param val Should adjustments be disabled?
 */
void ptu_power_ctrl_set_disable_power_amplifier_adjustments(bool val);

/** @brief Handle PTU tester power adjustment command.
 *  @param[in] cmd  The power control command to execute.
 */
void ptu_power_ctrl_set_itx_val(ptu_tester_command_t cmd);

#endif /* __PTU_PCTL_H__ */

/** @} */
