/* Copyright (c) 2013 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 *
 * @defgroup ptu_power_sharing PTU power sharing API
 * @{
 * @ingroup profile
 */

#ifndef PTU_POWER_SHARING_H__
#define PTU_POWER_SHARING_H__

#include <stdbool.h>
#include "ble_wpts_c.h"
#include "ptu.h"

/**@brief Initialize power sharing module.
 *
 * @param[in] sm_handler    State machine handler
 * @return NRF_ERROR_INVALID_PARAM if sm_handler is NULL, otherwise NRF_SUCCESS.
 */
uint32_t ptu_power_sharing_init(ptu_sm_handler_t sm_handler);

/**@brief Handle service events.
 *
 * @param[in] p_wpts_c         Handles.
 * @param[in] p_wpts_c_evt     Event data.
 */
void ptu_power_sharing_on_wpt_service_evt(ble_wpts_c_t * p_wpts_c, ble_wpts_c_evt_t * const p_wpts_c_evt);

/**@brief Inform power control module that PTU is having a high temperature warning.
 * When this occurs the power control module will instruct PRUs to lower their power
 * consumption.
 *
 * @param[in] warning   Temperature warning true or false.
 */
void ptu_power_sharing_temperature_warning_set(bool warning);

#endif /* PTU_POWER_SHARING_H__ */

/** @} */
