/* Copyright (c) 2013 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 *
 * @defgroup sm_ptu PTU State Machine
 * @{
 * @ingroup sm
 * @brief
 */

#ifndef PTU_SM_PTU_H__
#define PTU_SM_PTU_H__

#include <stdint.h>

/**@brief PTU Latch Fault reason type. */
typedef enum
{
    PTU_SM_LFR_PRU_SYSTEM_ERROR,
    PTU_SM_LFR_ROGUE_OBJCT_MODE_TRANS_FAILED,
    PTU_SM_LFR_ROGUE_OBJCT_DETECTED,
} sm_latch_fault_reason_t;

/**@brief PTU states. */
typedef enum
{
    PTU_SM_STATE_CONFIGURATION = 0,
    PTU_SM_STATE_POWER_SAVE,
    PTU_SM_STATE_LOW_POWER,
    PTU_SM_STATE_POWER_TRANSFER,
    PTU_SM_STATE_LATCH_FAULT,
    PTU_SM_STATE_LOCAL_FAULT,
    PTU_SM_STATE_COUNT
} ptu_sm_state_t;


/**@brief PTU signal type. */
typedef enum
{
    /* State Machine specific */
    PTU_SM_SIGNAL_NULL,
    PTU_SM_SIGNAL_CONFIGURATION_COMPLETE,
    PTU_SM_SIGNAL_LOCAL_FAULT,
    PTU_SM_SIGNAL_LOCAL_FAULT_CLEARED,
    PTU_SM_SIGNAL_REGISTRATION_TIMEOUT,
    PTU_SM_SIGNAL_CHARGE_START,
    PTU_SM_SIGNAL_PRU_ADV_RCVD,
    PTU_SM_SIGNAL_ALL_DEVICES_DISCONNECTED,
    PTU_SM_SIGNAL_PRU_ALL_CHARGE_COMPLETE,
    PTU_SM_SIGNAL_ROGUE_OBJECT_DETECTED,
    PTU_SM_SIGNAL_SYSTEM_ERROR,
    PTU_SM_SIGNAL_LATCHING_FAULT_CLEARED_BY_USER
} ptu_sm_signal_type_t;


/**@brief State machine state variables. */
typedef struct
{
    ptu_sm_state_t prev_state;             /**< Previous state. */
    ptu_sm_state_t current_state;          /**< Current state. */
    ptu_sm_state_t next_state;             /**< Next state. */
} ptu_sm_state_vars_t;

/******************************************************************************/
/** @name PTU SM functions.
 *  @{ */
/******************************************************************************/

/**@brief State machine input signal handler
 *
 * @param[in]  signal Signal data
 * @param[in]  p_state Current state variables
 * @return     The current state
 *
 */
ptu_sm_state_t ptu_sm_execute(ptu_sm_signal_type_t signal, ptu_sm_state_vars_t * p_state);

/** @} */

#endif // PTU_SM_PTU_H__
/** @} */
//lint -restore
