/* Copyright (c) 2013 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 *
 * @defgroup ptu_tmux PTU test multiplexer API
 * @{
 * @ingroup test_debug
 */

#ifndef __PTU_TEST_MUX_H__
#define __PTU_TEST_MUX_H__

#include <stdbool.h>
#include <stdint.h>
#include "test_mux_common.h"

/******************************************************************************
 * Types
 ******************************************************************************/

 /**
 * @struct ptu_tmux_override_t
 * @brief Collection of PTU HAL variables that can be overrided by test multiplexer.
 */
 typedef struct
{
    bool power_amp_enable;      /**< Test multiplexer override value */
    uint16_t power_amp_level;   /**< Test multiplexer override value */
    uint16_t vtx;               /**< Test multiplexer override value */
    uint16_t itx;               /**< Test multiplexer override value */
    uint16_t ptx;               /**< Test multiplexer override value */
    int16_t temperature;        /**< Test multiplexer override value */
} ptu_tmux_override_t;

/******************************************************************************
 * Profile API
 ******************************************************************************/

/**@brief Test wrapper for ptu_hal_poweramp_enable_set().
 *
 * @param[in]   enable value to be set.
 *
 * @retval      NRF_SUCCESS  Enabled successfully.
 */
uint32_t ptu_tmux_poweramp_enable_set(bool enable);

/**@brief Test wrapper for ptu_hal_poweramp_enable_get();.
 *
 * @param[out]  enable return value.
 *
 * @retval      NRF_SUCCESS  Enable was read successfully.
 */
uint32_t ptu_tmux_poweramp_enable_get(bool * enable);

/**@brief Test wrapper for ptu_hal_poweramp_level_set().
 *
 * @param[in]   level value to be set.
 *
 * @retval      NRF_SUCCESS  Value was set successfully.
 */
uint32_t ptu_tmux_poweramp_level_set(uint16_t level);

/**@brief Test wrapper for ptu_hal_poweramp_level_get().
 *
 * @param[out]   p_level return value.
 *
 * @retval      NRF_SUCCESS  Value was read successfully.
 */
uint32_t ptu_tmux_poweramp_level_get(uint16_t * p_level);

/**@brief Test wrapper for ptu_hal_itx_get().
 *
 * @param[out]   p_itx return value.
 *
 * @retval      NRF_SUCCESS  Value was read successfully.
 */
uint32_t ptu_tmux_itx_get(uint16_t * p_itx);

/**@brief Test wrapper for ptu_hal_vtx_get().
 *
 * @param[out]   p_vtx return value.
 *
 * @retval      NRF_SUCCESS  Value was read successfully.
 */
uint32_t ptu_tmux_vtx_get(uint16_t * p_vtx);

/**@brief Test wrapper for ptu_hal_ptx_get().
 *
 * @param[out]   p_ptx return value.
 *
 * @retval      NRF_SUCCESS    Value was read successfully.
 */
uint32_t ptu_tmux_ptx_get(uint16_t * p_ptx);


/**@brief Test wrapper for ptu_hal_temperature_get().
 *
 * @param[out]   p_temperature return value.
 *
 * @retval      NRF_SUCCESS    Value was read successfully.
 */
uint32_t ptu_tmux_temperature_get(int16_t * p_temperature);

/******************************************************************************
 * Test API
 ******************************************************************************/

/**@brief Set override values.
 *
 * @param[in]  values values to be written.
 */
void ptu_tmux_override_values_set(ptu_tmux_override_t * values);

/**@brief Get ovveride values.
 *
 * @param[out]  values returned override values.
 */
void ptu_tmux_override_values_get(ptu_tmux_override_t * values);

#endif /* __TMUX_H__ */
/** @} */
