/* Copyright (c) 2013 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

#include <stdint.h>
#include <stdbool.h>

/** @file
 *
 * @defgroup debug_api PTU / PRU debug API
 * @{
 * @ingroup test_debug
 */

 /** @brief WDI packet headers type. */
typedef enum
{
    DEBUG_POLL = 0,                     /**< WDI Packet type for polling the dongle */
    DEBUG_PKT  = 1,                     /**< Regular WDI packet */
    DEBUG_STR  = 2,                     /**< String packet */
    DEBUG_PTU  = 3,                     /**< PTU common command */
    DEBUG_PRU0 = 0x80,                  /**< PRU 0 data from PTU */
    DEBUG_PRU1 = 0x81,                  /**< PRU 1 data from PTU */
    DEBUG_PRU2 = 0x82,                  /**< PRU 2 data from PTU */
    DEBUG_PRU3 = 0x83,                  /**< PRU 3 data from PTU */
    DEBUG_PRU4 = 0x84,                  /**< PRU 4 data from PTU */
    DEBUG_PRU5 = 0x85,                  /**< PRU 5 data from PTU */
    DEBUG_PRU6 = 0x86,                  /**< PRU 6 data from PTU */
    DEBUG_PRU7 = 0x87                   /**< PRU 7 data from PTU */
} wdi_pkt_t;

 /**@brief Initialize SD Radio API
 * @returns Command status
 */
uint32_t sd_radio_init(void);

 /**@brief Check if debug command received from dongle
 *
 * @returns true    New command is available
 * @returns false   No command is available
 */
bool debug_cmd_available(void);

 /**@brief get debug command received from dongle
 *
 * @returns Command from dongle
 */
char get_debug_cmd(void);

/** @} */
