/* Copyright (c) Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file */

#include <string.h>
#include <stdio.h>

#include "simple_uart.h"
#include "app_print.h"

/**@brief Decomposes char array and send chars through UART TX.
 *
 * @param[in]     char_array     Message to sent through UART.
 */
void print_string(char * char_array)
{
  int size = strlen(char_array);

  while (size > 0)
  {
    size--;
    simple_uart_put(*char_array);
    char_array++;
  }
}

/**@brief Converts hex number into char and send it through UART TX.
 *
 * @param[in]     number        Number to send.
 * @param[in]     byte_size     Byte size of number to send.
 */
void print_hex(uint32_t number, uint8_t byte_size)
{
  int i;
  char hex_to_char[] = { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F' };

  for (i = ((byte_size*8)-4); i >= 0; i=i-4)
  {
    simple_uart_put((uint8_t)hex_to_char[number >> i & 0x0F]);
  }
}

/**@brief Function used to report event related to source code.
 *
 * @details Function used to provide more information of occurred errors.
 *          Might point on a line and a file when specific action occurred.
 *
 * @param[in]     line_num        Number of line in a source file.
 * @param[in]     file_name       Source file file-name.
 */
void print_file_and_line(uint16_t line_num, const uint8_t *file_name)
{
  char string[100];
  (void)sprintf(string,"Line: %04d, File: %s",line_num, file_name);
  print_string(string);
}
