/* Copyright (c) 2014 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

 /** @file */

#include "advertiser_beacon.h"
#include <stdio.h>
#include <string.h>

#include "nrf_soc.h"
#include "app_error.h"
#include "app_util.h"

#define APP_DEVICE_TYPE               0x02                      /**< 0x02 refers to Beacon */


/******************************************************************************/
/** @name Static functions and variables
 *  @{ */
/******************************************************************************/

/**@brief Struct containing all variables of this module */
static struct
{
    ble_beacon_init_t       init_vals;  //  Beacon inital values
    ble_gap_adv_params_t    adv_params; //  Advertisement paramters
} m_beacon;



/**@brief Initialize adv packet */
static uint8_t * m_get_adv_data(uint8_t * data_length)
{
    static uint8_t adv_pdu[31];
    uint8_t manuf_data_len_start_idx, beacon_data_len_start_idx;
    uint8_t offset    = 0;

    // Adding advertising data: Manufacturer specific data.
    adv_pdu[offset++]               =  0x00;                             // Manufacturer specific data length field (will be filled later).
    manuf_data_len_start_idx = offset;
    adv_pdu[offset++] =  BLE_GAP_AD_TYPE_MANUFACTURER_SPECIFIC_DATA;
    offset += uint16_encode(m_beacon.init_vals.manuf_id, &adv_pdu[offset]);
    adv_pdu[offset++] =  APP_DEVICE_TYPE;

    // Adding manufacturer specific data (beacon data).
    adv_pdu[offset++] =  0;                                              // Beacon data length field (will be filled later).
    beacon_data_len_start_idx = offset;
    memcpy(&adv_pdu[offset], &m_beacon.init_vals.uuid, sizeof(ble_uuid128_t));
    offset += sizeof(ble_uuid128_t);
    offset += uint16_encode(m_beacon.init_vals.major, &adv_pdu[offset]);
    offset += uint16_encode(m_beacon.init_vals.minor, &adv_pdu[offset]);
    adv_pdu[offset++] = m_beacon.init_vals.rssi;

    // Filling in length fields.
    adv_pdu[beacon_data_len_start_idx-1] = offset - beacon_data_len_start_idx;
    adv_pdu[manuf_data_len_start_idx-1]  = offset - manuf_data_len_start_idx;

    *data_length=offset;
    return &adv_pdu[0];
}

void app_beacon_init(ble_beacon_init_t * p_init)
{
    uint32_t err_code;
    uint8_t data_length;

    memcpy(&m_beacon.init_vals, p_init, sizeof(m_beacon.init_vals));
    memset(&m_beacon.adv_params, 0, sizeof(ble_gap_adv_params_t));
    m_beacon.adv_params.interval=m_beacon.init_vals.adv_interval;
    m_beacon.adv_params.type=BLE_GAP_ADV_TYPE_ADV_NONCONN_IND;

    err_code=sd_ble_gap_adv_data_set(m_get_adv_data(&data_length), data_length, 0, 0);
    APP_ERROR_CHECK(err_code);
}

void app_beacon_start(void)
{
    uint32_t err_code;
    err_code=sd_ble_gap_adv_start(&m_beacon.adv_params);
    APP_ERROR_CHECK(err_code);
}

void app_beacon_stop(void)
{
    uint32_t err_code;
    err_code=sd_ble_gap_adv_stop();
    APP_ERROR_CHECK(err_code);
}

/** @} */
