/* Copyright (c) 2013 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file */

#include <stdint.h>
#include <stdbool.h>
#include "ble.h"

#include "ble_srv_common.h"
#include "ble_wpts_common.h"
#include "nrf_assert.h"
#include "nrf_error.h"

bool wpts_uuids_initialized = false;                   /**< 128 bit UUIDs initialized */

/******************************************************************************/
/** @name Static functions and variables
 *  @{ */
/******************************************************************************/

static ble_uuid_t m_uuids128[BLE_WPTS_UUID128_CNT];    /**< Array of 128 bit UUIDs */

/** @} */

/******************************************************************************/
/** @name API implementation
 *  @{ */
/******************************************************************************/

uint32_t ble_wpts_uuid_init()
{
    uint32_t   err_code;
    uint8_t i;
    uint16_t uuid16;
    uint8_t    ref_byte;
    ble_uuid128_t uuid128 = {BLE_WPTS_UUID128_CHAR_BASE};
    ref_byte = uuid128.uuid128[BLE_WPTS_MODIFIED_BYTE];

    // Create 16-bit representations of 128-bit characteristics
    uuid16 = uint16_decode(&uuid128.uuid128[12]);
    for(i = 0; i < BLE_WPTS_UUID128_CNT; i++)
    {
        m_uuids128[i].uuid = uuid16;
    }

    // Add PRU Control char UUID
    uuid128.uuid128[BLE_WPTS_MODIFIED_BYTE] = (ref_byte + BLE_WPTS_UUID_PRU_CONTROL_CHAR_OFFSET);
    err_code = sd_ble_uuid_vs_add(&uuid128, &m_uuids128[BLE_WPTS_UUID128_PRU_CONTROL_CHAR].type);
    if (err_code != NRF_SUCCESS)
    {
        return err_code;
    }

    // Add PTU Static Parameter Char UUID
    uuid128.uuid128[BLE_WPTS_MODIFIED_BYTE] = (ref_byte + BLE_WPTS_UUID_PTU_STATIC_PARAMETER_CHAR_OFFSET);
    err_code = sd_ble_uuid_vs_add(&uuid128, &m_uuids128[BLE_WPTS_UUID128_PTU_STATIC_PARAMETER_CHAR].type);
    if (err_code != NRF_SUCCESS)
    {
        return err_code;
    }

    // Add PRU Alert Char UUID
    uuid128.uuid128[BLE_WPTS_MODIFIED_BYTE] = (ref_byte + BLE_WPTS_UUID_PRU_ALERT_CHAR_OFFSET);
    err_code = sd_ble_uuid_vs_add(&uuid128, &m_uuids128[BLE_WPTS_UUID128_PRU_ALERT_CHAR].type);
    if (err_code != NRF_SUCCESS)
    {
        return err_code;
    }

    // Add PRU Static Parameter Char UUID
    uuid128.uuid128[BLE_WPTS_MODIFIED_BYTE] = (ref_byte + BLE_WPTS_UUID_PRU_STATIC_PARAMETER_CHAR_OFFSET);
    err_code = sd_ble_uuid_vs_add(&uuid128, &m_uuids128[BLE_WPTS_UUID128_PRU_STATIC_PARAMETER_CHAR].type);
    if (err_code != NRF_SUCCESS)
    {
        return err_code;
    }

    // Add PRU Dynamic Parameter Char UUID
    uuid128.uuid128[BLE_WPTS_MODIFIED_BYTE] = (ref_byte + BLE_WPTS_UUID_PRU_DYNAMIC_PARAMETER_CHAR_OFFSET);
    err_code = sd_ble_uuid_vs_add(&uuid128, &m_uuids128[BLE_WPTS_UUID128_PRU_DYNAMIC_PARAMETER_CHAR].type);
    if (err_code != NRF_SUCCESS)
    {
        return err_code;
    }

    wpts_uuids_initialized = true;

    return NRF_SUCCESS;
}

void ble_wpts_uuid_get(ble_wpts_uuid128_t uuid128, ble_uuid_t * ble_uuid)
{
    ASSERT(wpts_uuids_initialized);
    *ble_uuid = m_uuids128[uuid128];
}

/** @} */
