/* Copyright (c) 2012 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file */

#include <string.h>
#include "pru_sm.h"

/******************************************************************************/
/** @name Static functions and variables
 *  @{ */
/******************************************************************************/

/**@brief Find the next state given the current state and the state machine event.
  *
  *@param signal   State machine signal.
  *@param p_state  Pointer to PRU state variable.
  *
  *@return The resulting state.
 */
static pru_sm_state_t m_get_next_state(pru_sm_signal_type_t signal, pru_sm_state_vars_t * p_state)
{
    pru_sm_state_t next_state = p_state->current_state;

    switch(p_state->current_state)
    {
        case PRU_SM_STATE_NULL:
            if(     signal == PRU_SM_SIGNAL_POWER_APPLIED)      next_state = PRU_SM_STATE_BOOT;
            break;

        case PRU_SM_STATE_BOOT:
            if(     signal == PRU_SM_SIGNAL_CHARGE_START)       next_state = PRU_SM_STATE_PRU_ON;
            else if(signal == PRU_SM_SIGNAL_POWER_REMOVED)      next_state = PRU_SM_STATE_NULL;
            else if(signal == PRU_SM_SIGNAL_SYSTEM_ERROR)       next_state = PRU_SM_STATE_SYSTEM_ERROR;
            break;

        case PRU_SM_STATE_PRU_ON:
            if(     signal == PRU_SM_SIGNAL_CHARGE_STOP)        next_state = PRU_SM_STATE_BOOT;
            else if(signal == PRU_SM_SIGNAL_CHARGE_COMPLETE)    next_state = PRU_SM_STATE_BOOT;
            else if(signal == PRU_SM_SIGNAL_DISCONNECTED)       next_state = PRU_SM_STATE_BOOT;
            else if(signal == PRU_SM_SIGNAL_POWER_REMOVED)      next_state = PRU_SM_STATE_NULL;
            else if(signal == PRU_SM_SIGNAL_SYSTEM_ERROR)       next_state = PRU_SM_STATE_SYSTEM_ERROR;
            break;

        case PRU_SM_STATE_SYSTEM_ERROR:
            if(     signal == PRU_SM_SIGNAL_POWER_REMOVED)      next_state = PRU_SM_STATE_NULL;
            break;

        default:
            break;
    }

    return next_state; // No state change
}
/** @} */

/******************************************************************************/
/** @name API implementation
 *  @{ */
/******************************************************************************/

pru_sm_state_t pru_sm_execute(pru_sm_signal_type_t signal, pru_sm_state_vars_t * p_state)
{
    static pru_sm_state_t current_state = PRU_SM_STATE_NULL;

    if(signal != PRU_SM_SIGNAL_NULL && p_state != NULL)
    {
        p_state->next_state = m_get_next_state(signal, p_state);
        p_state->prev_state = p_state->current_state;
        p_state->current_state = p_state->next_state;
        current_state = p_state->current_state;
    }

    return current_state;
}

/** @} */
