/* Copyright (c) 2013 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 */

#include <stdbool.h>
#include <stdint.h>
#include <string.h>

#include "pru_test_mux.h"
#include "pru_hal.h"
#include "nrf_error.h"
#include "nrf_assert.h"
#include "pru_hw_config.h"

/******************************************************************************/
/** @name Static functions and variables
 *  @{ */
/******************************************************************************/

static tmux_select_t get_mux_select;           /**< Multiplexer setting for **hal**get() functions  */
static tmux_select_t set_mux_select;           /**< Multiplexer setting for **hal**set() functions  */
static pru_tmux_override_t override_values;    /**< Collection of override values */

/**@brief Write all override values to **hal**set() functions
 * if overriding of **set functions is enabled.
 */
static void m_update_hal_from_override_values(void)
{
    if(set_mux_select == TMUX_SELECT_OVERRIDE)
    {
        (void)pru_hal_vout_enable_set(override_values.vout_enable);
    }
}

/** @} */

/******************************************************************************/
/** @name API implementation
 *  @{ */
/******************************************************************************/

uint32_t tmux_init(void)
{
    override_values.charge_complete = false;
    override_values.vout_enable = false;
    override_values.wired_charge_detect = false;
    override_values.iout = PRU_IOUT_DEFAULT;
    override_values.irect = PRU_IRECT_DEFAULT;
    override_values.temperature = PRU_TEMPERATURE_DEFAULT;
    override_values.vout = PRU_VOUT_DEFAULT;
    override_values.vrect = PRU_VRECT_DEFAULT;
    override_values.power_adjusted = PRU_ADJUSTED_DEFAULT;
    return pru_hal_init();
}

uint32_t pru_tmux_vrect_get(uint16_t * p_vrect)
{
    TMUX_GET(pru_hal_vrect_get, p_vrect, override_values.vrect);
}

uint32_t pru_tmux_irect_get(uint16_t * p_irect)
{
    TMUX_GET(pru_hal_irect_get, p_irect, override_values.irect);
}

uint32_t pru_tmux_vout_enable_get(bool * enable)
{
    TMUX_GET(pru_hal_vout_enable_get, enable, override_values.vout_enable);
}

uint32_t pru_tmux_vout_get(uint16_t * p_vout)
{
    TMUX_GET(pru_hal_vout_get, p_vout, override_values.vout);
}

uint32_t pru_tmux_iout_get(uint16_t * p_iout)
{
    TMUX_GET(pru_hal_iout_get, p_iout, override_values.iout);
}

uint32_t pru_tmux_temperature_get(int16_t * p_temperature)
{
    TMUX_GET(pru_hal_temperature_get, p_temperature, override_values.temperature);
}

uint32_t pru_tmux_wired_charge_detect_status_get(bool * p_wired)
{
    TMUX_GET(pru_hal_wired_charge_detect_status_get, p_wired, override_values.wired_charge_detect);
}

uint32_t pru_tmux_charge_complete_status_get(bool * p_charge_complete)
{
    TMUX_GET(pru_hal_charge_complete_status_get, p_charge_complete, override_values.charge_complete);
}

uint32_t pru_tmux_vout_enable_set(bool enable)
{
    TMUX_SET(pru_hal_vout_enable_set, enable);
}

uint32_t pru_tmux_adj_power_set(ctl_adj_power_t adj_setting)
{
    TMUX_SET(pru_hal_adj_power_set, adj_setting);
}

uint32_t pru_tmux_adj_power_get(ctl_adj_power_t * adj_setting)
{
    TMUX_GET(pru_hal_adj_power_get, adj_setting, override_values.adj_setting);
}

uint32_t pru_tmux_power_adjusted_get(bool * adjusted)
{
    TMUX_GET(pru_hal_power_adjusted_get, adjusted, override_values.power_adjusted);
}

uint32_t pru_tmux_power_adjusted_set(bool adjusted)
{
    TMUX_SET(pru_hal_power_adjusted_set, adjusted);
}
/******************************************************************************
 * Test API
 ******************************************************************************/

void tmux_get_select(tmux_select_t select)
{
    get_mux_select = select;
}

void tmux_set_select(tmux_select_t select)
{
    set_mux_select = select;
    m_update_hal_from_override_values();
}

void pru_tmux_override_values_set(pru_tmux_override_t * values)
{
    memcpy(&override_values, values, sizeof(pru_tmux_override_t));
    m_update_hal_from_override_values();
}

void pru_tmux_override_values_get(pru_tmux_override_t * values)
{
    memcpy(values, &override_values, sizeof(pru_tmux_override_t));
}

/** @} */
