/* Copyright (c) Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */


/** @file
 */

#include <stdbool.h>
#include <stdint.h>
#include <string.h>

#include "ptu_hw_config.h"
#include "nrf_error.h"
#include "nrf_assert.h"


/******************************************************************************/
/** @name Static functions and variables
 *  @{ */
/******************************************************************************/

static volatile uint16_t m_itx;                 /**< [mA] */
static volatile uint16_t m_vtx;                 /**< [mV] */
static volatile uint16_t m_temp;                /**< [Deg C] */
static volatile uint16_t m_poweramp_level;      /**< [implementation specific] */
static volatile bool m_poweramp_enable;         /**< [Deg C] */

/** @} */

/******************************************************************************/
/** @name API implementation
 *  @{ */
/******************************************************************************/

uint32_t ptu_hal_init(void)
{
    m_itx = PTU_ITX_DEFAULT;
    m_temp = PTU_TEMPERATUR_DEFAULT;
    m_vtx = PTU_VTX_DEFAULT;
    m_poweramp_level = PTU_POWERAMP_INPUT_DEFAULT;
    m_poweramp_enable = false;

    return NRF_SUCCESS;
}

uint32_t ptu_hal_poweramp_enable_set(bool enable)
{
    m_poweramp_enable = enable;
    return NRF_SUCCESS;
}

uint32_t ptu_hal_poweramp_enable_get(bool * enable)
{
    if (enable == NULL)
        return NRF_ERROR_INVALID_PARAM;
    *enable = m_poweramp_enable;
    return NRF_SUCCESS;
}

uint32_t ptu_hal_poweramp_level_set(uint16_t level)
{
    m_poweramp_level = level;
    return NRF_SUCCESS;
}

uint32_t ptu_hal_poweramp_level_get(uint16_t * level)
{
    if (level == NULL)
        return NRF_ERROR_INVALID_PARAM;
    *level = m_poweramp_level;
    return NRF_SUCCESS;
}

uint32_t ptu_hal_itx_get(uint16_t * p_itx)
{
    if (p_itx == NULL)
        return NRF_ERROR_INVALID_PARAM;
    *p_itx = m_itx;
    return NRF_SUCCESS;
}

uint32_t ptu_hal_vtx_get(uint16_t * p_vtx)
{
    if (p_vtx == NULL)
        return NRF_ERROR_INVALID_PARAM;
    *p_vtx = m_vtx;
    return NRF_SUCCESS;
}

uint32_t ptu_hal_ptx_get(uint16_t * p_ptx)
{
    if (p_ptx == NULL)
        return NRF_ERROR_INVALID_PARAM;
    *p_ptx = m_vtx * m_itx;
    return NRF_SUCCESS;
}

uint32_t ptu_hal_temperature_get(int16_t * p_temperature)
{
    if (p_temperature == NULL)
        return NRF_ERROR_INVALID_PARAM;
    *p_temperature = m_temp;
    return NRF_SUCCESS;
}
/** @} */
